<?php

namespace Drupal\graphql_vertex_ai\Plugin\GraphQL\DataProducer;

use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Google\Cloud\DiscoveryEngine\V1\SearchResponse;

/**
 * The data producer for search response summaries.
 *
 * @DataProducer(
 *   id = "vertex_ai_search_response_summary_citations",
 *   name = @Translation("Search response summary citations"),
 *   description = @Translation("The citations for the summary of the search response or null if empty."),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Summary citations")
 *   ),
 *   consumes = {
 *     "response" = @ContextDefinition("any",
 *       label = @Translation("Search Response"),
 *       required = TRUE
 *     ),
 *   }
 * )
 */
class VertexAiSearchResponseSummaryCitations extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param \Google\Cloud\DiscoveryEngine\V1\SearchResponse $response
   *   The search query.
   */
  public function resolve(SearchResponse $response): array {
    $citations = $response->getSummary()
      ->getSummaryWithMetadata()
      ->getCitationMetadata()
      ->getCitations()
      ->getIterator();
    return iterator_to_array($citations);
  }

}
